@@ -17,11 +17,14 @@ from .diagrams import (
 )
 from .tasks import add_task_interactive, display_tasks, edit_task, mark_task_done
 
-app_cli = typer.Typer()
+app_cli = typer.Typer(
+    help="DevNotes - Strumento per la gestione di note di sviluppo e task",
+    add_completion=True,
+)
 console = Console()
 
 # Crea un gruppo di comandi per Trello
-trello_app = typer.Typer()
+trello_app = typer.Typer(help="Comandi per l'integrazione con Trello")
 app_cli.add_typer(trello_app, name="trello", help="Comandi per l'integrazione con Trello")
 
 
@@ -273,7 +276,7 @@ def trello_create_board():
         console.print("pip install requests")
 
 
-@app_cli.command("set-project-name")
+@app_cli.command()
 def set_project_name(
     name: str = typer.Argument(..., help="Nuovo nome del progetto")
 ):
@@ -306,5 +309,30 @@ def set_project_name(
         update_project_name_on_trello(name)
 
 
+@app_cli.command()
+def setup_completion():
+    """
+    Mostra istruzioni su come abilitare l'autocompletamento dei comandi.
+    
+    Supporta Bash, Zsh e Fish.
+    """
+    console.print("[bold]Istruzioni per abilitare l'autocompletamento dei comandi[/bold]")
+    console.print("\n[yellow]Per Bash:[/yellow]")
+    console.print("Aggiungi questa riga al tuo file ~/.bashrc:")
+    console.print("[cyan]eval \"$(devnotes --completion bash)\"[/cyan]")
+    
+    console.print("\n[yellow]Per Zsh:[/yellow]")
+    console.print("Aggiungi questa riga al tuo file ~/.zshrc:")
+    console.print("[cyan]eval \"$(devnotes --completion zsh)\"[/cyan]")
+    
+    console.print("\n[yellow]Per Fish:[/yellow]")
+    console.print("Aggiungi questa riga al tuo file ~/.config/fish/config.fish:")
+    console.print("[cyan]eval (devnotes --completion fish)[/cyan]")
+    
+    console.print("\n[bold green]Dopo aver aggiunto la riga appropriata, riavvia il terminale o esegui 'source' sul file di configurazione.[/bold green]")
+    console.print("\nUna volta configurato, puoi digitare 'devnotes' seguito da TAB per vedere i comandi disponibili.")
+    console.print("Esempio: 'devnotes t<TAB>' mostrerà task-list, task-add-interactive, task-edit, task-done, trello")
+
+
 if __name__ == "__main__":
     app_cli()
